==> recruit-drop-list-1.0.22.tgz: package/lib/textbox.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";

/* eslint-disable */
import React, { Component } from 'react';
import { render } from 'react-dom';
import debounce from 'es6-promise-debounce';
import ToolTip from "@beisen-platform/ethos/lib/ToolTip";
import CommonLabel from '@beisen-platform/ethos/lib/CommonLabel';
import CommonInput from '@beisen/common-input';

var Textbox =
/*#__PURE__*/
function (_Component) {
  _inherits(Textbox, _Component);

  function Textbox(props) {
    var _this;

    _classCallCheck(this, Textbox);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Textbox).call(this, props));

    _this.tipsClick = function () {
      _this.setState({
        pointerEvent: "none",
        clickFocusing: true,
        showHiddenTips: 'none'
      });

      _this.refs.baseInput.focus();
    };

    _this.onMouseTip = function () {
      var self = _assertThisInitialized(_assertThisInitialized(_this)); //解决点击输入框时光标错位，引起原因是输入框上有层div导致


      setTimeout(function () {
        self.setState({
          mouseTips: true
        });
      }, 100);
    };

    _this.state = {
      defaultValue: props.defaultValue,
      hoverFocusing: false,
      clickFocusing: false,
      pointerEvent: "auto",
      showHiddenTips: 'block',
      mouseTips: false
    };
    _this.clearData = _this.clearData.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerFocus = _this.handlerFocus.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerBlur = _this.handlerBlur.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerClick = _this.handlerClick.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerOver = _this.handlerOver.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerOut = _this.handlerOut.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.onRealChange = _this.onRealChange.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerChange = debounce(_this.handlerChange, 300);
    return _this;
  }

  _createClass(Textbox, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.defaultValue != this.state.defaultValue) {
        this.setState({
          defaultValue: nextProps.defaultValue
        });

        if (this.refs.baseInput) {
          this.refs.baseInput.value = nextProps.defaultValue;
        }
      }
    }
    /*获得焦点*/

  }, {
    key: "handlerFocus",
    value: function handlerFocus(event) {
      this.callBackValue(event, "onFocus");
      this.clearToolTipDom();

      if (!this.props.readonly) {
        this.setState({
          clickFocusing: true
        });

        if (this.refs.baseInput.value !== "") {
          this.setState({
            hoverFocusing: true
          });
        }
      }
    }
  }, {
    key: "handlerChange",
    value: function handlerChange(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      this.callBackValue(event, "onChange");
      this.setState({
        defaultValue: this.refs.baseInput.value
      });
    }
  }, {
    key: "handlerClick",
    value: function handlerClick(event) {
      this.callBackValue(event, "onClick");
    }
  }, {
    key: "handlerBlur",
    value: function handlerBlur(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      this.callBackValue(event, "onBlur");
      var self = this;
      setTimeout(function () {
        self.setState({
          hoverFocusing: false,
          clickFocusing: false,
          pointerEvent: 'auto',
          showHiddenTips: 'block'
        });
      }, 300);
    }
  }, {
    key: "handlerOver",
    value: function handlerOver(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      if (this.state.clickFocusing) {
        return;
      } else if (this.refs.baseInput.value !== "") {
        this.setState({
          hoverFocusing: true
        });
      }
    }
  }, {
    key: "handlerOut",
    value: function handlerOut(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      } // let dom  (this.refs.mouseIconClose);
      // if (dom.className.indexOf('active') > 0) {
      //   return;
      // } else {


      this.setState({
        mouseTips: false,
        hoverFocusing: false
      });
      this.clearToolTipDom(); // }
    }
  }, {
    key: "clearToolTipDom",
    value: function clearToolTipDom() {
      var dom_1 = document.getElementsByClassName('tooltip')[0];
      var dom_2 = document.getElementsByClassName('tooltip-arrow')[0];

      if (dom_1 && dom_2) {
        var parNode = dom_1.parentNode;
        parNode.removeChild(dom_1);
        parNode.removeChild(dom_2);
      }
    }
  }, {
    key: "callBackValue",
    value: function callBackValue(event, status) {
      if (this.props.disabled) return false;
      this.props[status] && this.props[status](event, status, this.refs.baseInput.value);
    }
  }, {
    key: "clearData",
    value: function clearData(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      this.props.onBlur && this.props.onBlur(event, "onBlur", "");
      this.props.onChange && this.props.onChange(event, "onChange", "");
      this.refs.baseInput.value = "";
    }
  }, {
    key: "clearDown",
    value: function clearDown(event) {
      event.preventDefault();
    }
  }, {
    key: "onRealChange",
    value: function onRealChange(event) {
      event.persist();
      this.handlerChange(event);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          clickFocusing = _this$state.clickFocusing,
          defaultValue = _this$state.defaultValue,
          pointerEvent = _this$state.pointerEvent,
          hoverFocusing = _this$state.hoverFocusing,
          showHiddenTips = _this$state.showHiddenTips,
          mouseTips = _this$state.mouseTips;
      var _this$props = this.props,
          errorStatus = _this$props.errorStatus,
          errorMsg = _this$props.errorMsg,
          showText = _this$props.showText,
          hidden = _this$props.hidden,
          hiddenTip = _this$props.hiddenTip,
          disabled = _this$props.disabled,
          readonly = _this$props.readonly,
          placeHolder = _this$props.placeHolder,
          maxLength = _this$props.maxLength,
          hasClosebtn = _this$props.hasClosebtn;
      var inputClassName = 'u-input';
      var closeStyle = !readonly && !disabled && defaultValue && defaultValue.length > 0 && (hoverFocusing || clickFocusing) ? {
        display: 'block',
        marginRight: '5px'
      } : {
        display: 'none'
      };

      var _tempSymbol = readonly ? {
        "height": "14px",
        "display": "inline-block",
        "lineHeight": "14px",
        'position': 'absolute',
        'top': '0',
        'right': '20px'
      } : {
        "height": "14px",
        "display": "inline-block",
        "lineHeight": "14px"
      };

      if (defaultValue == '') {
        inputClassName = 'u-input u-input-noValue';
      }

      var inputStyle = !readonly && !disabled && defaultValue && defaultValue.length > 0 && (hoverFocusing || clickFocusing) ? {
        'maxWidth': 'calc(100% - 22px)'
      } : {};

      if (hidden) {
        return React.createElement("div", null);
      } else {
        return React.createElement("div", {
          className: "form-item"
        }, React.createElement(CommonLabel, this.props), readonly || disabled ? React.createElement(CommonInput, {
          readonly: true,
          errorStatus: errorStatus,
          errorMsg: errorMsg,
          defaultValue: defaultValue
        }) : React.createElement("div", {
          className: "form-item__control " + (clickFocusing ? 'form-item__control_is-active ' : '') + (showText && showText.length > 0 ? "form-item__control_has-info " : "") + (errorStatus ? 'form-item__control_is-active form-item__control_has-info form-item__control_has-error' : ''),
          onMouseEnter: this.handlerOver,
          onMouseLeave: this.handlerOut,
          ref: "mouseIconClose"
        }, mouseTips ? "" : React.createElement(ToolTip, {
          title: defaultValue,
          hidden: hiddenTip
        }, React.createElement("div", {
          className: "form-item_is-hidden-tips",
          onMouseEnter: this.onMouseTip,
          style: {
            pointerEvents: pointerEvent,
            display: showHiddenTips
          },
          onClick: this.tipsClick
        }, defaultValue)), React.createElement("input", {
          type: "text",
          style: inputStyle,
          className: inputClassName,
          placeholder: placeHolder,
          readOnly: readonly,
          disabled: disabled,
          onFocus: this.handlerFocus,
          onBlur: this.handlerBlur,
          onClick: this.handlerClick,
          defaultValue: defaultValue,
          onChange: this.onRealChange,
          maxLength: maxLength,
          ref: "baseInput"
        }), React.createElement("span", {
          className: "form-item__right-icon",
          onClick: this.clearData,
          onMouseDown: this.clearDown
        }, readonly ? React.createElement("i", {
          className: "u-icon pc-sys-bukebianji-nomal-svg disabled-icon",
          style: {
            position: 'absolute',
            right: '-1px',
            bottom: '-15px',
            width: '11px',
            height: '13px'
          }
        }) : '', hasClosebtn ? React.createElement("i", {
          className: "close-icon",
          style: closeStyle
        }) : '', React.createElement("span", {
          style: _tempSymbol
        }, this.props.symbol)), clickFocusing && showText && showText.length > 0 || errorStatus ? React.createElement("span", {
          className: "form-item__explain"
        }, errorStatus ? errorMsg : showText) : ''));
      }
    }
  }]);

  return Textbox;
}(Component);

Textbox.defaultProps = {
  hasClosebtn: true
};
export { Textbox as default };

==> recruit-drop-list-1.0.27.tgz: package/lib/textbox.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";

/* eslint-disable */
import React, { Component } from 'react';
import { render } from 'react-dom';
import debounce from 'es6-promise-debounce';
import ToolTip from "@beisen-platform/ethos/lib/ToolTip";
import CommonLabel from '@beisen-platform/ethos/lib/CommonLabel';
import CommonInput from '@beisen-platform/common-input';

var Textbox =
/*#__PURE__*/
function (_Component) {
  _inherits(Textbox, _Component);

  function Textbox(props) {
    var _this;

    _classCallCheck(this, Textbox);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Textbox).call(this, props));

    _this.tipsClick = function () {
      _this.setState({
        pointerEvent: "none",
        clickFocusing: true,
        showHiddenTips: 'none'
      });

      _this.refs.baseInput.focus();
    };

    _this.onMouseTip = function () {
      var self = _assertThisInitialized(_assertThisInitialized(_this)); //解决点击输入框时光标错位，引起原因是输入框上有层div导致


      setTimeout(function () {
        self.setState({
          mouseTips: true
        });
      }, 100);
    };

    _this.state = {
      defaultValue: props.defaultValue,
      hoverFocusing: false,
      clickFocusing: false,
      pointerEvent: "auto",
      showHiddenTips: 'block',
      mouseTips: false
    };
    _this.clearData = _this.clearData.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerFocus = _this.handlerFocus.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerBlur = _this.handlerBlur.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerClick = _this.handlerClick.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerOver = _this.handlerOver.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerOut = _this.handlerOut.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.onRealChange = _this.onRealChange.bind(_assertThisInitialized(_assertThisInitialized(_this)));
    _this.handlerChange = debounce(_this.handlerChange, 300);
    return _this;
  }

  _createClass(Textbox, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.defaultValue != this.state.defaultValue) {
        this.setState({
          defaultValue: nextProps.defaultValue
        });

        if (this.refs.baseInput) {
          this.refs.baseInput.value = nextProps.defaultValue;
        }
      }
    }
    /*获得焦点*/

  }, {
    key: "handlerFocus",
    value: function handlerFocus(event) {
      this.callBackValue(event, "onFocus");
      this.clearToolTipDom();

      if (!this.props.readonly) {
        this.setState({
          clickFocusing: true
        });

        if (this.refs.baseInput.value !== "") {
          this.setState({
            hoverFocusing: true
          });
        }
      }
    }
  }, {
    key: "handlerChange",
    value: function handlerChange(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      this.callBackValue(event, "onChange");
      this.setState({
        defaultValue: this.refs.baseInput.value
      });
    }
  }, {
    key: "handlerClick",
    value: function handlerClick(event) {
      this.callBackValue(event, "onClick");
    }
  }, {
    key: "handlerBlur",
    value: function handlerBlur(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      this.callBackValue(event, "onBlur");
      var self = this;
      setTimeout(function () {
        self.setState({
          hoverFocusing: false,
          clickFocusing: false,
          pointerEvent: 'auto',
          showHiddenTips: 'block'
        });
      }, 300);
    }
  }, {
    key: "handlerOver",
    value: function handlerOver(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      if (this.state.clickFocusing) {
        return;
      } else if (this.refs.baseInput.value !== "") {
        this.setState({
          hoverFocusing: true
        });
      }
    }
  }, {
    key: "handlerOut",
    value: function handlerOut(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      } // let dom  (this.refs.mouseIconClose);
      // if (dom.className.indexOf('active') > 0) {
      //   return;
      // } else {


      this.setState({
        mouseTips: false,
        hoverFocusing: false
      });
      this.clearToolTipDom(); // }
    }
  }, {
    key: "clearToolTipDom",
    value: function clearToolTipDom() {
      var dom_1 = document.getElementsByClassName('tooltip')[0];
      var dom_2 = document.getElementsByClassName('tooltip-arrow')[0];

      if (dom_1 && dom_2) {
        var parNode = dom_1.parentNode;
        parNode.removeChild(dom_1);
        parNode.removeChild(dom_2);
      }
    }
  }, {
    key: "callBackValue",
    value: function callBackValue(event, status) {
      if (this.props.disabled) return false;
      this.props[status] && this.props[status](event, status, this.refs.baseInput.value);
    }
  }, {
    key: "clearData",
    value: function clearData(event) {
      if (this.props.readonly || this.props.disabled) {
        return;
      }

      this.props.onBlur && this.props.onBlur(event, "onBlur", "");
      this.props.onChange && this.props.onChange(event, "onChange", "");
      this.refs.baseInput.value = "";
    }
  }, {
    key: "clearDown",
    value: function clearDown(event) {
      event.preventDefault();
    }
  }, {
    key: "onRealChange",
    value: function onRealChange(event) {
      event.persist();
      this.handlerChange(event);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$state = this.state,
          clickFocusing = _this$state.clickFocusing,
          defaultValue = _this$state.defaultValue,
          pointerEvent = _this$state.pointerEvent,
          hoverFocusing = _this$state.hoverFocusing,
          showHiddenTips = _this$state.showHiddenTips,
          mouseTips = _this$state.mouseTips;
      var _this$props = this.props,
          errorStatus = _this$props.errorStatus,
          errorMsg = _this$props.errorMsg,
          showText = _this$props.showText,
          hidden = _this$props.hidden,
          hiddenTip = _this$props.hiddenTip,
          disabled = _this$props.disabled,
          readonly = _this$props.readonly,
          placeHolder = _this$props.placeHolder,
          maxLength = _this$props.maxLength,
          hasClosebtn = _this$props.hasClosebtn;
      var inputClassName = 'u-input';
      var closeStyle = !readonly && !disabled && defaultValue && defaultValue.length > 0 && (hoverFocusing || clickFocusing) ? {
        display: 'block',
        marginRight: '5px'
      } : {
        display: 'none'
      };

      var _tempSymbol = readonly ? {
        "height": "14px",
        "display": "inline-block",
        "lineHeight": "14px",
        'position': 'absolute',
        'top': '0',
        'right': '20px'
      } : {
        "height": "14px",
        "display": "inline-block",
        "lineHeight": "14px"
      };

      if (defaultValue == '') {
        inputClassName = 'u-input u-input-noValue';
      }

      var inputStyle = !readonly && !disabled && defaultValue && defaultValue.length > 0 && (hoverFocusing || clickFocusing) ? {
        'maxWidth': 'calc(100% - 22px)'
      } : {};

      if (hidden) {
        return React.createElement("div", null);
      } else {
        return React.createElement("div", {
          className: "form-item"
        }, React.createElement(CommonLabel, this.props), readonly || disabled ? React.createElement(CommonInput, {
          readonly: true,
          errorStatus: errorStatus,
          errorMsg: errorMsg,
          defaultValue: defaultValue
        }) : React.createElement("div", {
          className: "form-item__control " + (clickFocusing ? 'form-item__control_is-active ' : '') + (showText && showText.length > 0 ? "form-item__control_has-info " : "") + (errorStatus ? 'form-item__control_is-active form-item__control_has-info form-item__control_has-error' : ''),
          onMouseEnter: this.handlerOver,
          onMouseLeave: this.handlerOut,
          ref: "mouseIconClose"
        }, mouseTips ? "" : React.createElement(ToolTip, {
          title: defaultValue,
          hidden: hiddenTip
        }, React.createElement("div", {
          className: "form-item_is-hidden-tips",
          onMouseEnter: this.onMouseTip,
          style: {
            pointerEvents: pointerEvent,
            display: showHiddenTips
          },
          onClick: this.tipsClick
        }, defaultValue)), React.createElement("input", {
          type: "text",
          style: inputStyle,
          className: inputClassName,
          placeholder: placeHolder,
          readOnly: readonly,
          disabled: disabled,
          onFocus: this.handlerFocus,
          onBlur: this.handlerBlur,
          onClick: this.handlerClick,
          defaultValue: defaultValue,
          onChange: this.onRealChange,
          maxLength: maxLength,
          ref: "baseInput"
        }), React.createElement("span", {
          className: "form-item__right-icon",
          onClick: this.clearData,
          onMouseDown: this.clearDown
        }, readonly ? React.createElement("i", {
          className: "u-icon pc-sys-bukebianji-nomal-svg disabled-icon",
          style: {
            position: 'absolute',
            right: '-1px',
            bottom: '-15px',
            width: '11px',
            height: '13px'
          }
        }) : '', hasClosebtn ? React.createElement("i", {
          className: "close-icon",
          style: closeStyle
        }) : '', React.createElement("span", {
          style: _tempSymbol
        }, this.props.symbol)), clickFocusing && showText && showText.length > 0 || errorStatus ? React.createElement("span", {
          className: "form-item__explain"
        }, errorStatus ? errorMsg : showText) : ''));
      }
    }
  }]);

  return Textbox;
}(Component);

Textbox.defaultProps = {
  hasClosebtn: true
};
export { Textbox as default };
